@@ -12,7 +12,7 @@ impl FeroxFilter for EmptyFilter {
 
     /// Compare one EmptyFilter to another
     fn box_eq(&self, other: &dyn Any) -> bool {
-        other.downcast_ref::<Self>().map_or(false, |a| self == a)
+        other.downcast_ref::<Self>() == Some(self)
     }
 
     /// Return self as Any for dynamic dispatch purposes
