@@ -12,18 +12,18 @@ pub struct SizeFilter {
 impl FeroxFilter for SizeFilter {
     /// Check `content_length` against what was passed in via -S|--filter-size
     fn should_filter_response(&self, response: &FeroxResponse) -> bool {
-        log::trace!("enter: should_filter_response({:?} {})", self, response);
+        log::trace!("enter: should_filter_response({self:?} {response})");
 
         let result = response.content_length() == self.content_length;
 
-        log::trace!("exit: should_filter_response -> {}", result);
+        log::trace!("exit: should_filter_response -> {result}");
 
         result
     }
 
     /// Compare one SizeFilter to another
     fn box_eq(&self, other: &dyn Any) -> bool {
-        other.downcast_ref::<Self>().map_or(false, |a| self == a)
+        other.downcast_ref::<Self>() == Some(self)
     }
 
     /// Return self as Any for dynamic dispatch purposes
