@@ -2,13 +2,13 @@ use std::collections::HashMap;
 use std::sync::Arc;
 
 use anyhow::{bail, Result};
+use console::style;
 use futures::future;
 use scraper::{Html, Selector};
 use uuid::Uuid;
 
-use crate::filters::{SimilarityFilter, WildcardFilter, SIM_HASHER};
+use crate::filters::{SimilarityFilter, WildcardFilter};
 use crate::message::FeroxMessage;
-use crate::nlp::preprocess;
 use crate::scanner::RESPONSES;
 use crate::{
     config::OutputLevel,
@@ -80,7 +80,7 @@ impl HeuristicTests {
     /// is 32 characters long. So, a length of 1 return a 32 character string,
     /// a length of 2 returns a 64 character string, and so on...
     fn unique_string(&self, length: usize) -> String {
-        log::trace!("enter: unique_string({})", length);
+        log::trace!("enter: unique_string({length})");
         let mut ids = vec![];
 
         for _ in 0..length {
@@ -89,7 +89,7 @@ impl HeuristicTests {
 
         let unique_id = ids.join("");
 
-        log::trace!("exit: unique_string -> {}", unique_id);
+        log::trace!("exit: unique_string -> {unique_id}");
         unique_id
     }
 
@@ -99,7 +99,7 @@ impl HeuristicTests {
     ///
     /// Any urls that are found to be alive are returned to the caller.
     pub async fn connectivity(&self, target_urls: &[String]) -> Result<Vec<String>> {
-        log::trace!("enter: connectivity_test({:?})", target_urls);
+        log::trace!("enter: connectivity_test({target_urls:?})");
 
         let mut good_urls = vec![];
 
@@ -119,10 +119,8 @@ impl HeuristicTests {
                         OutputLevel::Default | OutputLevel::Quiet
                     ) {
                         if e.to_string().contains(":SSL") {
-                            ferox_print(
-                                &format!("Could not connect to {target_url} due to SSL errors (run with -k to ignore), skipping...\n  => {}\n", e.root_cause()),
-                                &PROGRESS_PRINTER,
-                            );
+                            let msg = format!("Could not connect to {target_url} due to {} errors (run with {} to ignore), skipping...\n  => {}\n",style("SSL").red(), style("--insecure").yellow().bright(), e.root_cause());
+                            ferox_print(&msg, &PROGRESS_PRINTER);
                         } else {
                             ferox_print(
                                 &format!(
@@ -133,7 +131,7 @@ impl HeuristicTests {
                             );
                         }
                     }
-                    log::warn!("{}", e);
+                    log::warn!("{e}");
                 }
             }
         }
@@ -142,13 +140,13 @@ impl HeuristicTests {
             bail!("Could not connect to any target provided");
         }
 
-        log::trace!("exit: connectivity_test -> {:?}", good_urls);
+        log::trace!("exit: connectivity_test -> {good_urls:?}");
         Ok(good_urls)
     }
 
     /// heuristic designed to detect when a server has directory listing enabled
     pub async fn directory_listing(&self, target_url: &str) -> Result<Option<DirListingResult>> {
-        log::trace!("enter: directory_listing({})", target_url);
+        log::trace!("enter: directory_listing({target_url})");
 
         let tgt = if !target_url.ends_with('/') {
             // if left unchanged, this function would be called against redirects that point to
@@ -171,6 +169,7 @@ impl HeuristicTests {
             &url.target,
             DEFAULT_METHOD,
             self.handles.config.output_level,
+            self.handles.config.response_size_limit,
         )
         .await;
 
@@ -201,14 +200,14 @@ impl HeuristicTests {
                 .send(Command::WriteToDisk(Box::new(ferox_msg)))
                 .unwrap_or_default();
 
-            log::info!("{}", msg);
+            log::info!("{msg}");
 
             let result = DirListingResult {
                 dir_list_type: dirlist_type,
                 response: ferox_response,
             };
 
-            log::trace!("exit: directory_listing -> {:?}", result);
+            log::trace!("exit: directory_listing -> {result:?}");
             return Ok(Some(result));
         }
 
@@ -242,7 +241,7 @@ impl HeuristicTests {
             };
 
             if dirlist_type.is_some() {
-                log::trace!("exit: detect_directory_listing -> {:?}", dirlist_type);
+                log::trace!("exit: detect_directory_listing -> {dirlist_type:?}");
                 return dirlist_type;
             }
         }
@@ -258,7 +257,7 @@ impl HeuristicTests {
         &self,
         target_url: &str,
     ) -> Result<Option<WildcardResult>> {
-        log::trace!("enter: detect_404_like_responses({:?})", target_url);
+        log::trace!("enter: detect_404_like_responses({target_url:?})");
 
         if self.handles.config.dont_filter {
             // early return, dont_filter scans don't need tested
@@ -287,7 +286,7 @@ impl HeuristicTests {
         // and then we want to add any extensions that was specified
         // or has since been added to the running config
         for ext in &self.handles.config.extensions {
-            extensions.push(format!(".{}", ext));
+            extensions.push(format!(".{ext}"));
         }
 
         // for every method, attempt to id its 404 response
@@ -356,6 +355,7 @@ impl HeuristicTests {
                             &ferox_url.target,
                             method,
                             self.handles.config.output_level,
+                            self.handles.config.response_size_limit,
                         )
                         .await,
                     )
@@ -409,7 +409,7 @@ impl HeuristicTests {
 
                             // if we're here, we've found a new wildcard that we didn't previously display, print it
                             if print_sentry {
-                                ferox_print(&format!("{}", new_wildcard), &PROGRESS_PRINTER);
+                                ferox_print(&format!("{new_wildcard}"), &PROGRESS_PRINTER);
                             }
                         }
                     }
@@ -424,12 +424,7 @@ impl HeuristicTests {
                 //
                 // in addition, we'll create a similarity filter as a fallback
                 for resp in wildcard_responses {
-                    let hash = SIM_HASHER.create_signature(preprocess(resp.text()).iter());
-
-                    let sim_filter = SimilarityFilter {
-                        hash,
-                        original_url: resp.url().to_string(),
-                    };
+                    let sim_filter = SimilarityFilter::from(resp);
 
                     self.handles
                         .filters
